from typing import List

from rdflib import Graph

from ..ns import *
from .declarations.Entity import Entity


class Collection(Entity):
    __type__ = L0["Collection"]

    hasMember: List[Entity] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasMember:
            for hasMember in self.hasMember:
                g.add((self.uriRef, L0["hasMember"], hasMember.uriRef))



from .DayOfWeek import DayOfWeek
from .Duration import Duration
from .MonthOfYear import MonthOfYear
from .TemporalEntity import TemporalEntity
from .TimeIndexedEvent import TimeIndexedEvent
from .TimeInstant import TimeInstant
from .TimeInterval import TimeInterval
from .Year import Year



from typing import List

from rdflib import Graph, Literal

from ..ns import *
from ..Thing import Thing
from .PointOfInterest import PointOfInterest


class PointOfInterestCategory(Thing):
    __type__ = POI["PointOfInterestCategory"]

    POIcategoryName: List[Literal] = None
    isPOICategoryFor: PointOfInterest = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        for POIcategoryName in self.POIcategoryName:
            g.add((self.uriRef, POI["hasPOICategory"], POIcategoryName))

        if self.isPOICategoryFor:
            g.add((self.uriRef, POI["isPOICategoryFor"],
                  self.isPOICategoryFor.uriRef))



from typing import List

from rdflib import Graph, Literal

from ..ns import *
from .Organization import Organization
from .PublicOrgActivityType import PublicOrgActivityType
from .PublicOrganizationCategory import PublicOrganizationCategory


class PublicOrganization(Organization):
    __type__ = COV["PublicOrganization"]

    hasPublicOrgActivityType: List[PublicOrgActivityType] = None
    hasCategory: PublicOrganizationCategory = None
    IPAcode: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasPublicOrgActivityType:
            for hasPublicOrgActivityType in self.hasPublicOrgActivityType:
                g.add(
                    (self.uriRef, COV["hasPublicOrgActivityType"], hasPublicOrgActivityType.uriRef))

        if self.hasCategory:
            g.add((self.uriRef, COV["hasCategory"], self.hasCategory.uriRef))

        if self.IPAcode:
            g.add((self.uriRef, COV["IPAcode"], self.IPAcode))



from typing import List

from rdflib import Graph

from ..ns import *
from ..l0.Concept import Concept
from .Telephone import Telephone


class TelephoneType(Concept):
    __type__ = SM["TelephoneType"]

    isTelephoneTypeOf: List[Telephone] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isTelephoneTypeOf:
            for isTelephoneTypeOf in self.isTelephoneTypeOf:
                g.add(
                    (self.uriRef, SM["isTelephoneTypeOf"], isTelephoneTypeOf.uriRef))



from rdflib import Graph, Literal

from ..ns import *
from ..ti.TimeIndexedEvent import TimeIndexedEvent
from .Organization import Organization
from .ParticipationType import ParticipationType


class Partecipation(TimeIndexedEvent):
    __type__ = COV["Partecipation"]

    participated: Organization = None
    hasParticipationType: ParticipationType = None
    participationPercentage: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.participated:
            for participated in self.participated:
                g.add((self.uriRef, COV["participated"], participated.uriRef))

        if self.hasParticipationType:
            for hasParticipationType in self.hasParticipationType:
                g.add(
                    (self.uriRef, COV["hasParticipationType"], hasParticipationType.uriRef))

        if self.participationPercentage:
            for participationPercentage in self.participationPercentage:
                g.add(
                    (self.uriRef, COV["participationPercentage"], participationPercentage))



from rdflib import Graph, Literal

from ..ns import *
from ..l0.Object import Object
from .OnlineContactPoint import OnlineContactPoint
from .TelephoneType import TelephoneType


class Telephone(Object):
    __type__ = SM["Telephone"]

    hasTelephoneType: TelephoneType = None
    isTelephoneOf: OnlineContactPoint = None
    telephoneNumber: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasTelephoneType:
            g.add((self.uriRef, SM["hasTelephoneType"],
                  self.hasTelephoneType.uriRef))

        if self.isTelephoneOf:
            g.add((self.uriRef, SM["isTelephoneOf"],
                  self.isTelephoneOf.uriRef))

        if self.telephoneNumber:
            g.add((self.uriRef, SM["telephoneNumber"], self.telephoneNumber))



from typing import List

from rdflib import Graph, Literal

from ..ns import *
from .Organization import Organization


class SupportUnit(Organization):
    __type__ = COV["SupportUnit"]

    isSupportUnitOf: List[Organization] = None
    officeIdentifier: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isSupportUnitOf:
            for isSupportUnitOf in self.isSupportUnitOf:
                g.add(
                    (self.uriRef, COV["isSupportUnitOf"], isSupportUnitOf.uriRef))

        if self.officeIdentifier:
            for officeIdentifier in self.officeIdentifier:
                g.add((self.uriRef, COV["officeIdentifier"], officeIdentifier))
